# Textual Query Sandbox

A quick spur-of-the-moment hack that will likely grow into something a wee
bit more useful. For now though, it's a simple/pragmatic tool for quickly
testing [Textual queries](https://textual.textualize.io/guide/queries/).

## Installation

Install either with `pip` or (ideally) `pipx`:

```sh
$ pipx install textual-query-sandbox
```

Then run `tqs`. That's it!

![Textual Query Sandbox](https://raw.githubusercontent.com/davep/textual-query-sandbox/main/tqs.png)

[//]: # (README.md ends here)
